Widjet
======

What is it?
-----------
Widjet is a Javascript framework and programming style for developing web applications
in a component based style. The framework itself is lightweight, the current version is 23kb of Javascript.

These properties are considered typical for an application written in Widjet style:

* The application is made by composing and nesting widgets.
* Each widget creates and manages the DOM nodes necessary.
* Each widget handles events by and the structure of DOM nodes.
* The visual style of each widget should preferably be done using CSS.
* The application is not post-back intensive.
* There are no excessive manipulation of DOM nodes using id and class selectors.

Widjet does not require, but can be used together with other Javascript frameworks.
The target web browsers are IE8+(due to market share) and recent versions of Chrome, Safari, Firefox and Opera.

Hello, world
------------
The typical Hello, world example in a Widjet component looks like this:

First include Widjet.js

    <script src="../Widjet.js"></script>

Then in another script tag write this:

    var HelloWorldWidget = function(className) {
        var helloWorld = Widjet.ui.Element("div", className);
        helloWorld.text("Hello, world!");
        return helloWorld;
    };

Then we have to insert an instance of HelloWorldWidget into the DOM when the page is done loading.
It's preferable to have an existing div that is converted into a Widjet.ui.Panel.

     function init() {
        Widjet.init();
        var panel = Widjet.ui.Panel();
        panel.adoptNodeById("myContainer");

        var helloWorld = HelloWorldWidget("HelloWorld");
        panel.addWidget(helloWorld);
     }

    <body onload="init();">
        <div id="myContainer">
        </div>
    </body>

If you inspect the DOM after the page has loaded you will find:

    <div class="HelloWorld">
        Hello, world!
    </div>

See below for some examples that involve events and nesting of widgets.

Examples
--------
Visit the [demo page](http://tomhal.github.com/Widjet/) to try some live example widgets.

What about Internet Explorer 6-7, mobile browsers and touch support?
--------------------------------------------------------------------

* Internet Explorer versions earlier than 8 will of course not be specifically excluded, but I will not do testing using them.
* Recent mobile browsers should work just fine with Widjet.
* Touch support will have to wait a bit until the project is more mature.

License
-------
Widjet is licensed under the MIT license. See the LICENSE file if you want to read the license.
